@@ -7,7 +7,7 @@ def print_lol(the_list, level):
 			print_lol(each_item, level+1)
 		else:
 			for tab_stop in range(level):
-				print("\t",)
+				print("\t"),
 			print(each_item)
 
 if __name__ == '__main__':
